==> hyphenate-sdk-lite-3.3.9-sources.jar: com/hyphenate/chat/EMConference.java <==
package com.hyphenate.chat;

/**
 * Created by lzan13 on 2017/8/17.
 *
 * \~chinese
 * 多人会议实体类，保存会议信息
 *
 * \~english
 * Multi person conference entity class, save conference information
 */
public class EMConference {

    private String pubStreamId = "";
    private String conferenceId = "";
    private String password = "";
    private String extension = "";

    /**
     * \~chinese
     * 获取本地 Stream id
     *
     * \~english
     * Get local stream id
     */
    public String getPubStreamId() {
        return pubStreamId;
    }

    /**
     * \~chinese
     * 设置本地 Stream id
     *
     * \~english
     * Set local stream id
     */
    public void setPubStreamId(String pubStreamId) {
        this.pubStreamId = pubStreamId;
    }

    /**
     * \~chinese
     * 获取会议 ID
     *
     * \~english
     * Get conference id
     */
    public String getConferenceId() {
        return conferenceId;
    }

    /**
     * \~chinese
     * 设置会议 ID
     *
     * \~english
     * Set conference id
     */
    public void setConferenceId(String conferenceId) {
        this.conferenceId = conferenceId;
    }

    /**
     * \~chinese
     * 获取会议密码
     *
     * \~english
     * Get conference password
     */
    public String getPassword() {
        return password;
    }

    /**
     * \~chinese
     * 设置会议密码
     *
     * \~english
     * Set conference password
     */
    public void setPassword(String password) {
        this.password = password;
    }

    /**
     * \~chinese
     * 获取会议扩展信息
     *
     * \~english
     * Get conference support information
     */
    public String getExtension() {
        return extension;
    }

    /**
     * \~chinese
     * 设置会议扩展信息
     *
     * \~english
     * Set conference support information
     */
    public void setExtension(String extension) {
        this.extension = extension;
    }

    /**
     * \~chinese
     * 会议结束时，重置会议信息
     *
     * \~english
     * Exit conference reset conference information
     */
    public void reset() {
        conferenceId = "";
        password = "";
        extension = "";
    }
}

==> hyphenate-sdk-lite-3.4.0-sources.jar: com/hyphenate/chat/EMConference.java <==
package com.hyphenate.chat;

/**
 * Created by lzan13 on 2017/8/17.
 *
 * \~chinese
 * 多人会议实体类，保存会议信息
 *
 * \~english
 * Multi person conference entity class, save conference information
 */
public class EMConference {

    private String pubNormalId = "";
    private String pubDesktopId = "";
    private String conferenceId = "";
    private String password = "";
    private String extension = "";

    /**
     * \~chinese
     * 获取本地推送的流 id
     * @param type 流类型
     *
     * \~english
     * Get local publish stream id
     * @param type Stream type
     */
    public String getPubStreamId(EMConferenceStream.StreamType type){
        if (type == EMConferenceStream.StreamType.DESKTOP) {
            return pubDesktopId;
        }
        return pubNormalId;
    }

    /**
     * \~chinese
     * 设置本地推送的流 id
     * @param pubStreamId 流 Id
     * @param type 流类型
     *
     * \~english
     * Set local publish normal stream id
     * @param pubStreamId Stream id
     * @param type Stream type
     */
    public void setPubStreamId(String pubStreamId, EMConferenceStream.StreamType type) {
        if(type == EMConferenceStream.StreamType.NORMAL){
            pubNormalId = pubStreamId;
        }else if (type == EMConferenceStream.StreamType.DESKTOP) {
            pubDesktopId = pubStreamId;
        }
    }

    /**
     * \~chinese
     * 获取会议 ID
     *
     * \~english
     * Get conference id
     */
    public String getConferenceId() {
        return conferenceId;
    }

    /**
     * \~chinese
     * 设置会议 ID
     *
     * \~english
     * Set conference id
     */
    public void setConferenceId(String conferenceId) {
        this.conferenceId = conferenceId;
    }

    /**
     * \~chinese
     * 获取会议密码
     *
     * \~english
     * Get conference password
     */
    public String getPassword() {
        return password;
    }

    /**
     * \~chinese
     * 设置会议密码
     *
     * \~english
     * Set conference password
     */
    public void setPassword(String password) {
        this.password = password;
    }

    /**
     * \~chinese
     * 获取会议扩展信息
     *
     * \~english
     * Get conference support information
     */
    public String getExtension() {
        return extension;
    }

    /**
     * \~chinese
     * 设置会议扩展信息
     *
     * \~english
     * Set conference support information
     */
    public void setExtension(String extension) {
        this.extension = extension;
    }

    /**
     * \~chinese
     * 会议结束时，重置会议信息
     *
     * \~english
     * Exit conference reset conference information
     */
    public void reset() {
        conferenceId = "";
        password = "";
        extension = "";
    }
}
